@@ -3,6 +3,7 @@
 #  Date:           17-Jun-2021 jdw
 #
 #  Updated:
+#  3-Mar-2023 aae fix method typo
 #
 ##
 """
@@ -15,6 +16,7 @@ import logging
 import os.path
 import time
 
+from rcsb.utils.chemref.PharosProvider import PharosProvider
 from rcsb.utils.io.FileUtil import FileUtil
 from rcsb.utils.io.MarshalUtil import MarshalUtil
 from rcsb.utils.io.StashableBase import StashableBase
@@ -98,11 +100,16 @@ class PharosTargetActivityProvider(StashableBase):
         targetD = {}
         cofactorFilePath = os.path.join(self.__cachePath, "Pharos-targets", "drug_activity.tdd")
         cfDL = self.__mU.doImport(cofactorFilePath, fmt="tdd", rowFormat="dict")
-        targetD = self.__extactCofactorData(cfDL)
+        targetD = self.__extractCofactorData(cfDL)
+        drgIdS = self.__extractDrugIdentifiers(cfDL)
         #
         cofactorFilePath = os.path.join(self.__cachePath, "Pharos-targets", "cmpd_activity.tdd")
         cfDL = self.__mU.doImport(cofactorFilePath, fmt="tdd", rowFormat="dict")
-        targetD.update(self.__extactCofactorData(cfDL))
+        targetD.update(self.__extractCofactorData(cfDL))
+        cmpIdS = self.__extractCompoundIdentifiers(cfDL)
+        chemblIdList = list(cmpIdS.union(drgIdS))
+        phP = PharosProvider(cachePath=self.__cachePath, useCache=False)
+        phP.load(chemblIdList, "identifiers", fmt="json", indent=0)
         #
         targetFilePath = os.path.join(self.__cachePath, "Pharos-targets", "protein.tdd")
         tDL = self.__mU.doImport(targetFilePath, fmt="tdd", rowFormat="dict")
@@ -118,7 +125,32 @@ class PharosTargetActivityProvider(StashableBase):
         ok = self.__mU.doExport(self.getTargetActivityDataPath(), {"version": vS, "created": tS, "activity": targetD, "targets": targetDetailsD}, fmt="json", indent=3)
         return ok
 
-    def __extactCofactorData(self, cfDL):
+    def fetchCompoundIdentifiers(self):
+        cofactorFilePath = os.path.join(self.__cachePath, "Pharos-targets", "drug_activity.tdd")
+        cfDL = self.__mU.doImport(cofactorFilePath, fmt="tdd", rowFormat="dict")
+        drgIdS = self.__extractDrugIdentifiers(cfDL)
+        #
+        cofactorFilePath = os.path.join(self.__cachePath, "Pharos-targets", "cmpd_activity.tdd")
+        cfDL = self.__mU.doImport(cofactorFilePath, fmt="tdd", rowFormat="dict")
+        cmpIdS = self.__extractCompoundIdentifiers(cfDL)
+        chemblIdList = list(cmpIdS.union(drgIdS))
+        return chemblIdList
+
+    def __extractCompoundIdentifiers(self, cfDL):
+        chemblIdS = set()
+        for cfD in cfDL:
+            if cfD["catype"].upper() == "CHEMBL":
+                chemblIdS.add(cfD["cmpd_id_in_src"])
+        return chemblIdS
+
+    def __extractDrugIdentifiers(self, cfDL):
+        chemblIdS = set()
+        for cfD in cfDL:
+            if cfD["cmpd_chemblid"] and cfD["cmpd_chemblid"].startswith("CHEM"):
+                chemblIdS.add(cfD["cmpd_chemblid"])
+        return chemblIdS
+
+    def __extractCofactorData(self, cfDL):
         """Extract ids, activity and moa data for drugs and cofactors from the Pharos schema dump files.
 
         Args:
